@@ -526,7 +526,7 @@
 * Comment out this if block if EMIN is ok
          IF( IWARN ) THEN
             FIRST = .TRUE.
-            WRITE( 6, FMT = 9999 )LEMIN
+** Commented out by Pierre            WRITE( 6, FMT = 9999 )LEMIN
          END IF
 ***
 *
